==> ferite-1.0.0.tar.gz: ferite-1.0.0/modules/posix/util_user.c <==
/*
 * Copyright (C) 2001-2005 Chris Ross, Stephan Engstrom, Alex Holden et al
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 * o Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * o Neither the name of the ferite software nor the names of its contributors may
 *   be used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include "util_user.h"

int system_sync_pwent_to_self( FeriteScript *script, FeriteObject *self, struct passwd *pw )
{
    FeriteVariable *v;
    v = ferite_object_get_var(script,self,"pw_name");
    ferite_str_set( VAS(v), pw->pw_name, 0, FE_CHARSET_DEFAULT );
    v = ferite_object_get_var(script,self,"pw_passwd");
    ferite_str_set( VAS(v), pw->pw_passwd, 0, FE_CHARSET_DEFAULT );
    v = ferite_object_get_var(script,self,"pw_uid");
    VAI(v) = pw->pw_uid;
    v = ferite_object_get_var(script,self,"pw_gid");
    VAI(v) = pw->pw_gid;
    v = ferite_object_get_var(script,self,"pw_gecos");
    ferite_str_set( VAS(v), pw->pw_gecos, 0, FE_CHARSET_DEFAULT );
    v = ferite_object_get_var(script,self,"pw_dir");
    ferite_str_set( VAS(v), pw->pw_shell, 0, FE_CHARSET_DEFAULT );
    v = ferite_object_get_var(script,self,"pw_shell");
    ferite_str_set( VAS(v), pw->pw_shell, 0, FE_CHARSET_DEFAULT );
    return 0;
}

==> ferite-1.1.17.tar.gz: ferite-1.1.17/modules/posix/util_user.c <==
/*
 * Copyright (C) 2001-2007 Chris Ross, Stephan Engstrom, Alex Holden et al
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 * o Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * o Neither the name of the ferite software nor the names of its contributors may
 *   be used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include "util_user.h"

int system_sync_pwent_to_self( FeriteScript *script, FeriteObject *self, struct passwd *pw )
{
    FeriteVariable *v;
    v = ferite_object_get_var(script,self,"pw_name");
    ferite_str_set( script, VAS(v), pw->pw_name, 0, FE_CHARSET_DEFAULT );
    v = ferite_object_get_var(script,self,"pw_passwd");
    ferite_str_set( script, VAS(v), pw->pw_passwd, 0, FE_CHARSET_DEFAULT );
    v = ferite_object_get_var(script,self,"pw_uid");
    VAI(v) = pw->pw_uid;
    v = ferite_object_get_var(script,self,"pw_gid");
    VAI(v) = pw->pw_gid;
    v = ferite_object_get_var(script,self,"pw_gecos");
    ferite_str_set( script, VAS(v), pw->pw_gecos, 0, FE_CHARSET_DEFAULT );
    v = ferite_object_get_var(script,self,"pw_dir");
    ferite_str_set( script, VAS(v), pw->pw_shell, 0, FE_CHARSET_DEFAULT );
    v = ferite_object_get_var(script,self,"pw_shell");
    ferite_str_set( script, VAS(v), pw->pw_shell, 0, FE_CHARSET_DEFAULT );
    return 0;
}
